==> ejc-settle-api-3.0.0-20240607.084741-15-sources.jar: com/ejianc/business/settle/bean/SettlementCenterBudgetFeeVO.java <==
package com.ejianc.business.settle.bean;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.List;


/**
 * 其他费用
 *
 * @author generator
 */
public class SettlementCenterBudgetFeeVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long budgetId; // 预算书主键
    private String detailIndex; // 序号
    private Long parentId; // 父ID
    private String feeCode; // 编码
    private String feeName; // 名称
    private String feeFeature; // 特征
    private BigDecimal feeTaxRate; // 税率
    private BigDecimal feeMny; // 承包合同合价(无税)
    private BigDecimal feeTaxMny; // 承包合同合价(含税)
    private BigDecimal feeTax; // 承包合同税额
    private BigDecimal quoteFeeMny; // 对甲结算产值(无税)
    private BigDecimal quoteFeeTaxMny; // 对甲结产值(含税)
    private BigDecimal quoteFeeTax; // 结算产值税额
    private BigDecimal settlementCenterFeeMny; // 统计产值(无税)
    private BigDecimal settlementCenterFeeTaxMny; // 统计产值(含税)
    private BigDecimal settlementCenterFeeTax; // 统计产值税额
    private String feeMemo; // 备注
    private Integer leafFlag; // 是否末级
    private Long feeSubjectId; // 成本科目id
    private String feeSubjectName; // 成本科目名称
    private String feeUnit; // 单位
    private BigDecimal feeNum; // 承包合同工程量
    private BigDecimal quoteFeeNum; // 对甲结算工程量
    private BigDecimal settlementCenterFeeNum; // 统计工程量
    private BigDecimal feePrice; // 综合单价(无税)
    private BigDecimal feeTaxPrice; // 综合单价(含税)
    private Long dcDrwgrpInfo; // settlement_center_dc_drwgrp_info主键 0 代表 为预算书缓存

    private List<SettlementCenterBudgetFeeVO> children;


    public Long getDcDrwgrpInfo() {
        return dcDrwgrpInfo;
    }

    public void setDcDrwgrpInfo(Long dcDrwgrpInfo) {
        this.dcDrwgrpInfo = dcDrwgrpInfo;
    }

    public Long getBudgetId() {
        return budgetId;
    }

    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }

    public String getDetailIndex() {
        return detailIndex;
    }

    public void setDetailIndex(String detailIndex) {
        this.detailIndex = detailIndex;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getFeeCode() {
        return feeCode;
    }

    public void setFeeCode(String feeCode) {
        this.feeCode = feeCode;
    }

    public String getFeeName() {
        return feeName;
    }

    public void setFeeName(String feeName) {
        this.feeName = feeName;
    }

    public String getFeeFeature() {
        return feeFeature;
    }

    public void setFeeFeature(String feeFeature) {
        this.feeFeature = feeFeature;
    }

    public BigDecimal getFeeTaxRate() {
        return feeTaxRate;
    }

    public void setFeeTaxRate(BigDecimal feeTaxRate) {
        this.feeTaxRate = feeTaxRate;
    }

    public BigDecimal getFeeMny() {
        return feeMny;
    }

    public void setFeeMny(BigDecimal feeMny) {
        this.feeMny = feeMny;
    }

    public BigDecimal getFeeTaxMny() {
        return feeTaxMny;
    }

    public void setFeeTaxMny(BigDecimal feeTaxMny) {
        this.feeTaxMny = feeTaxMny;
    }

    public BigDecimal getFeeTax() {
        return feeTax;
    }

    public void setFeeTax(BigDecimal feeTax) {
        this.feeTax = feeTax;
    }

    public BigDecimal getQuoteFeeMny() {
        return quoteFeeMny;
    }

    public void setQuoteFeeMny(BigDecimal quoteFeeMny) {
        this.quoteFeeMny = quoteFeeMny;
    }

    public BigDecimal getQuoteFeeTaxMny() {
        return quoteFeeTaxMny;
    }

    public void setQuoteFeeTaxMny(BigDecimal quoteFeeTaxMny) {
        this.quoteFeeTaxMny = quoteFeeTaxMny;
    }

    public BigDecimal getQuoteFeeTax() {
        return quoteFeeTax;
    }

    public void setQuoteFeeTax(BigDecimal quoteFeeTax) {
        this.quoteFeeTax = quoteFeeTax;
    }

    public BigDecimal getSettlementCenterFeeMny() {
        return settlementCenterFeeMny;
    }

    public void setSettlementCenterFeeMny(BigDecimal settlementCenterFeeMny) {
        this.settlementCenterFeeMny = settlementCenterFeeMny;
    }

    public BigDecimal getSettlementCenterFeeTaxMny() {
        return settlementCenterFeeTaxMny;
    }

    public void setSettlementCenterFeeTaxMny(BigDecimal settlementCenterFeeTaxMny) {
        this.settlementCenterFeeTaxMny = settlementCenterFeeTaxMny;
    }

    public BigDecimal getSettlementCenterFeeTax() {
        return settlementCenterFeeTax;
    }

    public void setSettlementCenterFeeTax(BigDecimal settlementCenterFeeTax) {
        this.settlementCenterFeeTax = settlementCenterFeeTax;
    }

    public String getFeeMemo() {
        return feeMemo;
    }

    public void setFeeMemo(String feeMemo) {
        this.feeMemo = feeMemo;
    }

    public Integer getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Integer leafFlag) {
        this.leafFlag = leafFlag;
    }

    public Long getFeeSubjectId() {
        return feeSubjectId;
    }

    public void setFeeSubjectId(Long feeSubjectId) {
        this.feeSubjectId = feeSubjectId;
    }

    public String getFeeSubjectName() {
        return feeSubjectName;
    }

    public void setFeeSubjectName(String feeSubjectName) {
        this.feeSubjectName = feeSubjectName;
    }

    public String getFeeUnit() {
        return feeUnit;
    }

    public void setFeeUnit(String feeUnit) {
        this.feeUnit = feeUnit;
    }

    public BigDecimal getFeeNum() {
        return feeNum;
    }

    public void setFeeNum(BigDecimal feeNum) {
        this.feeNum = feeNum;
    }

    public BigDecimal getQuoteFeeNum() {
        return quoteFeeNum;
    }

    public void setQuoteFeeNum(BigDecimal quoteFeeNum) {
        this.quoteFeeNum = quoteFeeNum;
    }

    public BigDecimal getSettlementCenterFeeNum() {
        return settlementCenterFeeNum;
    }

    public void setSettlementCenterFeeNum(BigDecimal settlementCenterFeeNum) {
        this.settlementCenterFeeNum = settlementCenterFeeNum;
    }

    public BigDecimal getFeePrice() {
        return feePrice;
    }

    public void setFeePrice(BigDecimal feePrice) {
        this.feePrice = feePrice;
    }

    public BigDecimal getFeeTaxPrice() {
        return feeTaxPrice;
    }

    public void setFeeTaxPrice(BigDecimal feeTaxPrice) {
        this.feeTaxPrice = feeTaxPrice;
    }

    public List<SettlementCenterBudgetFeeVO> getChildren() {
        return children;
    }

    public void setChildren(List<SettlementCenterBudgetFeeVO> children) {
        this.children = children;
    }
}

==> ejc-settle-api-3.0.0-20240618.032527-57-sources.jar: com/ejianc/business/settle/bean/SettlementCenterBudgetFeeVO.java <==
package com.ejianc.business.settle.bean;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.List;


/**
 * 其他费用
 *
 * @author generator
 */
public class SettlementCenterBudgetFeeVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long budgetId; // 预算书主键
    private String detailIndex; // 序号
    private Long parentId; // 父ID
    private String feeCode; // 编码
    private String feeName; // 名称
    private String feeFeature; // 特征
    private BigDecimal feeTaxRate; // 税率
    private BigDecimal feeMny; // 承包合同合价(无税)
    private BigDecimal feeTaxMny; // 承包合同合价(含税)
    private BigDecimal feeTax; // 承包合同税额
    private BigDecimal quoteFeeMny; // 对甲结算产值(无税)
    private BigDecimal quoteFeeTaxMny; // 对甲结产值(含税)
    private BigDecimal quoteFeeTax; // 结算产值税额
    private BigDecimal settlementCenterFeeMny; // 统计产值(无税)
    private BigDecimal settlementCenterFeeTaxMny; // 统计产值(含税)
    private BigDecimal settlementCenterFeeTax; // 统计产值税额
    private String feeMemo; // 备注
    private Integer leafFlag; // 是否末级
    private Long feeSubjectId; // 成本科目id
    private String feeSubjectName; // 成本科目名称
    private String feeUnit; // 单位
    private BigDecimal feeNum; // 承包合同工程量
    private BigDecimal quoteFeeNum; // 对甲结算工程量
    private BigDecimal settlementCenterFeeNum; // 统计工程量
    private BigDecimal feePrice; // 综合单价(无税)
    private BigDecimal feeTaxPrice; // 综合单价(含税)
    private Long dcDrwgrpInfo; // settlement_center_dc_drwgrp_info主键 0 代表 为预算书缓存

    private String errorMessage;//错误信息集合
    private Integer rowIndex;

    private List<SettlementCenterBudgetFeeVO> children;


    public Long getDcDrwgrpInfo() {
        return dcDrwgrpInfo;
    }

    public void setDcDrwgrpInfo(Long dcDrwgrpInfo) {
        this.dcDrwgrpInfo = dcDrwgrpInfo;
    }

    public Long getBudgetId() {
        return budgetId;
    }

    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }

    public String getDetailIndex() {
        return detailIndex;
    }

    public void setDetailIndex(String detailIndex) {
        this.detailIndex = detailIndex;
    }

    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }

    public String getFeeCode() {
        return feeCode;
    }

    public void setFeeCode(String feeCode) {
        this.feeCode = feeCode;
    }

    public String getFeeName() {
        return feeName;
    }

    public void setFeeName(String feeName) {
        this.feeName = feeName;
    }

    public String getFeeFeature() {
        return feeFeature;
    }

    public void setFeeFeature(String feeFeature) {
        this.feeFeature = feeFeature;
    }

    public BigDecimal getFeeTaxRate() {
        return feeTaxRate;
    }

    public void setFeeTaxRate(BigDecimal feeTaxRate) {
        this.feeTaxRate = feeTaxRate;
    }

    public BigDecimal getFeeMny() {
        return feeMny;
    }

    public void setFeeMny(BigDecimal feeMny) {
        this.feeMny = feeMny;
    }

    public BigDecimal getFeeTaxMny() {
        return feeTaxMny;
    }

    public void setFeeTaxMny(BigDecimal feeTaxMny) {
        this.feeTaxMny = feeTaxMny;
    }

    public BigDecimal getFeeTax() {
        return feeTax;
    }

    public void setFeeTax(BigDecimal feeTax) {
        this.feeTax = feeTax;
    }

    public BigDecimal getQuoteFeeMny() {
        return quoteFeeMny;
    }

    public void setQuoteFeeMny(BigDecimal quoteFeeMny) {
        this.quoteFeeMny = quoteFeeMny;
    }

    public BigDecimal getQuoteFeeTaxMny() {
        return quoteFeeTaxMny;
    }

    public void setQuoteFeeTaxMny(BigDecimal quoteFeeTaxMny) {
        this.quoteFeeTaxMny = quoteFeeTaxMny;
    }

    public BigDecimal getQuoteFeeTax() {
        return quoteFeeTax;
    }

    public void setQuoteFeeTax(BigDecimal quoteFeeTax) {
        this.quoteFeeTax = quoteFeeTax;
    }

    public BigDecimal getSettlementCenterFeeMny() {
        return settlementCenterFeeMny;
    }

    public void setSettlementCenterFeeMny(BigDecimal settlementCenterFeeMny) {
        this.settlementCenterFeeMny = settlementCenterFeeMny;
    }

    public BigDecimal getSettlementCenterFeeTaxMny() {
        return settlementCenterFeeTaxMny;
    }

    public void setSettlementCenterFeeTaxMny(BigDecimal settlementCenterFeeTaxMny) {
        this.settlementCenterFeeTaxMny = settlementCenterFeeTaxMny;
    }

    public BigDecimal getSettlementCenterFeeTax() {
        return settlementCenterFeeTax;
    }

    public void setSettlementCenterFeeTax(BigDecimal settlementCenterFeeTax) {
        this.settlementCenterFeeTax = settlementCenterFeeTax;
    }

    public String getFeeMemo() {
        return feeMemo;
    }

    public void setFeeMemo(String feeMemo) {
        this.feeMemo = feeMemo;
    }

    public Integer getLeafFlag() {
        return leafFlag;
    }

    public void setLeafFlag(Integer leafFlag) {
        this.leafFlag = leafFlag;
    }

    public Long getFeeSubjectId() {
        return feeSubjectId;
    }

    public void setFeeSubjectId(Long feeSubjectId) {
        this.feeSubjectId = feeSubjectId;
    }

    public String getFeeSubjectName() {
        return feeSubjectName;
    }

    public void setFeeSubjectName(String feeSubjectName) {
        this.feeSubjectName = feeSubjectName;
    }

    public String getFeeUnit() {
        return feeUnit;
    }

    public void setFeeUnit(String feeUnit) {
        this.feeUnit = feeUnit;
    }

    public BigDecimal getFeeNum() {
        return feeNum;
    }

    public void setFeeNum(BigDecimal feeNum) {
        this.feeNum = feeNum;
    }

    public BigDecimal getQuoteFeeNum() {
        return quoteFeeNum;
    }

    public void setQuoteFeeNum(BigDecimal quoteFeeNum) {
        this.quoteFeeNum = quoteFeeNum;
    }

    public BigDecimal getSettlementCenterFeeNum() {
        return settlementCenterFeeNum;
    }

    public void setSettlementCenterFeeNum(BigDecimal settlementCenterFeeNum) {
        this.settlementCenterFeeNum = settlementCenterFeeNum;
    }

    public BigDecimal getFeePrice() {
        return feePrice;
    }

    public void setFeePrice(BigDecimal feePrice) {
        this.feePrice = feePrice;
    }

    public BigDecimal getFeeTaxPrice() {
        return feeTaxPrice;
    }

    public void setFeeTaxPrice(BigDecimal feeTaxPrice) {
        this.feeTaxPrice = feeTaxPrice;
    }

    public List<SettlementCenterBudgetFeeVO> getChildren() {
        return children;
    }

    public void setChildren(List<SettlementCenterBudgetFeeVO> children) {
        this.children = children;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    public Integer getRowIndex() {
        return rowIndex;
    }

    public void setRowIndex(Integer rowIndex) {
        this.rowIndex = rowIndex;
    }
}
